@@ -24,10 +24,12 @@
 //------------------------------------------------------------------------------
 #include <rpc/rpc.h>
 //------------------------------------------------------------------------------
-namespace rpcgen
+namespace NST
+{
+namespace API
+{
+namespace NFS3
 {
-
-extern "C" {
 
 const uint32_t NFS3_FHSIZE         {64};
 const uint32_t NFS3_COOKIEVERFSIZE {8};
@@ -949,142 +951,9 @@ typedef struct COMMIT3res COMMIT3res;
 
 #define NFS_V3 3
 
-bool_t xdr_uint64 (XDR *, uint64*);
-bool_t xdr_uint32 (XDR *, uint32*);
-bool_t xdr_int64 (XDR *, int64*);
-bool_t xdr_int32 (XDR *, int32*);
-bool_t xdr_filename3 (XDR *, filename3*);
-bool_t xdr_nfspath3 (XDR *, nfspath3*);
-bool_t xdr_fileid3 (XDR *, fileid3*);
-bool_t xdr_cookie3 (XDR *, cookie3*);
-bool_t xdr_cookieverf3 (XDR *, cookieverf3);
-bool_t xdr_createverf3 (XDR *, createverf3);
-bool_t xdr_writeverf3 (XDR *, writeverf3);
-bool_t xdr_uid3 (XDR *, uid3*);
-bool_t xdr_gid3 (XDR *, gid3*);
-bool_t xdr_size3 (XDR *, size3*);
-bool_t xdr_offset3 (XDR *, offset3*);
-bool_t xdr_mode3 (XDR *, mode3*);
-bool_t xdr_count3 (XDR *, count3*);
-bool_t xdr_nfsstat3 (XDR *, nfsstat3*);
-bool_t xdr_ftype3 (XDR *, ftype3*);
-bool_t xdr_specdata3 (XDR *, specdata3*);
-bool_t xdr_nfs_fh3 (XDR *, nfs_fh3*);
-bool_t xdr_nfstime3 (XDR *, nfstime3*);
-bool_t xdr_fattr3 (XDR *, fattr3*);
-bool_t xdr_post_op_attr (XDR *, post_op_attr*);
-bool_t xdr_wcc_attr (XDR *, wcc_attr*);
-bool_t xdr_pre_op_attr (XDR *, pre_op_attr*);
-bool_t xdr_wcc_data (XDR *, wcc_data*);
-bool_t xdr_post_op_fh3 (XDR *, post_op_fh3*);
-bool_t xdr_time_how (XDR *, time_how*);
-bool_t xdr_set_mode3 (XDR *, set_mode3*);
-bool_t xdr_set_uid3 (XDR *, set_uid3*);
-bool_t xdr_set_gid3 (XDR *, set_gid3*);
-bool_t xdr_set_size3 (XDR *, set_size3*);
-bool_t xdr_set_atime (XDR *, set_atime*);
-bool_t xdr_set_mtime (XDR *, set_mtime*);
-bool_t xdr_sattr3 (XDR *, sattr3*);
-bool_t xdr_diropargs3 (XDR *, diropargs3*);
-bool_t xdr_NULL3args (XDR *, NULL3args*); // for compatibility
-bool_t xdr_NULL3res (XDR *, NULL3res*);   // for compatibility
-bool_t xdr_GETATTR3args (XDR *, GETATTR3args*);
-bool_t xdr_GETATTR3resok (XDR *, GETATTR3resok*);
-bool_t xdr_GETATTR3res (XDR *, GETATTR3res*);
-bool_t xdr_sattrguard3 (XDR *, sattrguard3*);
-bool_t xdr_SETATTR3args (XDR *, SETATTR3args*);
-bool_t xdr_SETATTR3resok (XDR *, SETATTR3resok*);
-bool_t xdr_SETATTR3resfail (XDR *, SETATTR3resfail*);
-bool_t xdr_SETATTR3res (XDR *, SETATTR3res*);
-bool_t xdr_LOOKUP3args (XDR *, LOOKUP3args*);
-bool_t xdr_LOOKUP3resok (XDR *, LOOKUP3resok*);
-bool_t xdr_LOOKUP3resfail (XDR *, LOOKUP3resfail*);
-bool_t xdr_LOOKUP3res (XDR *, LOOKUP3res*);
-bool_t xdr_ACCESS3args (XDR *, ACCESS3args*);
-bool_t xdr_ACCESS3resok (XDR *, ACCESS3resok*);
-bool_t xdr_ACCESS3resfail (XDR *, ACCESS3resfail*);
-bool_t xdr_ACCESS3res (XDR *, ACCESS3res*);
-bool_t xdr_READLINK3args (XDR *, READLINK3args*);
-bool_t xdr_READLINK3resok (XDR *, READLINK3resok*);
-bool_t xdr_READLINK3resfail (XDR *, READLINK3resfail*);
-bool_t xdr_READLINK3res (XDR *, READLINK3res*);
-bool_t xdr_READ3args (XDR *, READ3args*);
-bool_t xdr_READ3resok (XDR *, READ3resok*);
-bool_t xdr_READ3resfail (XDR *, READ3resfail*);
-bool_t xdr_READ3res (XDR *, READ3res*);
-bool_t xdr_stable_how (XDR *, stable_how*);
-bool_t xdr_WRITE3args (XDR *, WRITE3args*);
-bool_t xdr_WRITE3resok (XDR *, WRITE3resok*);
-bool_t xdr_WRITE3resfail (XDR *, WRITE3resfail*);
-bool_t xdr_WRITE3res (XDR *, WRITE3res*);
-bool_t xdr_createmode3 (XDR *, createmode3*);
-bool_t xdr_createhow3 (XDR *, createhow3*);
-bool_t xdr_CREATE3args (XDR *, CREATE3args*);
-bool_t xdr_CREATE3resok (XDR *, CREATE3resok*);
-bool_t xdr_CREATE3resfail (XDR *, CREATE3resfail*);
-bool_t xdr_CREATE3res (XDR *, CREATE3res*);
-bool_t xdr_MKDIR3args (XDR *, MKDIR3args*);
-bool_t xdr_MKDIR3resok (XDR *, MKDIR3resok*);
-bool_t xdr_MKDIR3resfail (XDR *, MKDIR3resfail*);
-bool_t xdr_MKDIR3res (XDR *, MKDIR3res*);
-bool_t xdr_symlinkdata3 (XDR *, symlinkdata3*);
-bool_t xdr_SYMLINK3args (XDR *, SYMLINK3args*);
-bool_t xdr_SYMLINK3resok (XDR *, SYMLINK3resok*);
-bool_t xdr_SYMLINK3resfail (XDR *, SYMLINK3resfail*);
-bool_t xdr_SYMLINK3res (XDR *, SYMLINK3res*);
-bool_t xdr_devicedata3 (XDR *, devicedata3*);
-bool_t xdr_mknoddata3 (XDR *, mknoddata3*);
-bool_t xdr_MKNOD3args (XDR *, MKNOD3args*);
-bool_t xdr_MKNOD3resok (XDR *, MKNOD3resok*);
-bool_t xdr_MKNOD3resfail (XDR *, MKNOD3resfail*);
-bool_t xdr_MKNOD3res (XDR *, MKNOD3res*);
-bool_t xdr_REMOVE3args (XDR *, REMOVE3args*);
-bool_t xdr_REMOVE3resok (XDR *, REMOVE3resok*);
-bool_t xdr_REMOVE3resfail (XDR *, REMOVE3resfail*);
-bool_t xdr_REMOVE3res (XDR *, REMOVE3res*);
-bool_t xdr_RMDIR3args (XDR *, RMDIR3args*);
-bool_t xdr_RMDIR3resok (XDR *, RMDIR3resok*);
-bool_t xdr_RMDIR3resfail (XDR *, RMDIR3resfail*);
-bool_t xdr_RMDIR3res (XDR *, RMDIR3res*);
-bool_t xdr_RENAME3args (XDR *, RENAME3args*);
-bool_t xdr_RENAME3resok (XDR *, RENAME3resok*);
-bool_t xdr_RENAME3resfail (XDR *, RENAME3resfail*);
-bool_t xdr_RENAME3res (XDR *, RENAME3res*);
-bool_t xdr_LINK3args (XDR *, LINK3args*);
-bool_t xdr_LINK3resok (XDR *, LINK3resok*);
-bool_t xdr_LINK3resfail (XDR *, LINK3resfail*);
-bool_t xdr_LINK3res (XDR *, LINK3res*);
-bool_t xdr_READDIR3args (XDR *, READDIR3args*);
-bool_t xdr_entry3 (XDR *, entry3*);
-bool_t xdr_dirlist3 (XDR *, dirlist3*);
-bool_t xdr_READDIR3resok (XDR *, READDIR3resok*);
-bool_t xdr_READDIR3resfail (XDR *, READDIR3resfail*);
-bool_t xdr_READDIR3res (XDR *, READDIR3res*);
-bool_t xdr_READDIRPLUS3args (XDR *, READDIRPLUS3args*);
-bool_t xdr_entryplus3 (XDR *, entryplus3*);
-bool_t xdr_dirlistplus3 (XDR *, dirlistplus3*);
-bool_t xdr_READDIRPLUS3resok (XDR *, READDIRPLUS3resok*);
-bool_t xdr_READDIRPLUS3resfail (XDR *, READDIRPLUS3resfail*);
-bool_t xdr_READDIRPLUS3res (XDR *, READDIRPLUS3res*);
-bool_t xdr_FSSTAT3args (XDR *, FSSTAT3args*);
-bool_t xdr_FSSTAT3resok (XDR *, FSSTAT3resok*);
-bool_t xdr_FSSTAT3resfail (XDR *, FSSTAT3resfail*);
-bool_t xdr_FSSTAT3res (XDR *, FSSTAT3res*);
-bool_t xdr_FSINFO3args (XDR *, FSINFO3args*);
-bool_t xdr_FSINFO3resok (XDR *, FSINFO3resok*);
-bool_t xdr_FSINFO3resfail (XDR *, FSINFO3resfail*);
-bool_t xdr_FSINFO3res (XDR *, FSINFO3res*);
-bool_t xdr_PATHCONF3args (XDR *, PATHCONF3args*);
-bool_t xdr_PATHCONF3resok (XDR *, PATHCONF3resok*);
-bool_t xdr_PATHCONF3resfail (XDR *, PATHCONF3resfail*);
-bool_t xdr_PATHCONF3res (XDR *, PATHCONF3res*);
-bool_t xdr_COMMIT3args (XDR *, COMMIT3args*);
-bool_t xdr_COMMIT3resok (XDR *, COMMIT3resok*);
-bool_t xdr_COMMIT3resfail (XDR *, COMMIT3resfail*);
-bool_t xdr_COMMIT3res (XDR *, COMMIT3res*);
-}
-
-} // namespace rpcgen
+} // namespace NFS3
+} // namespace API
+} // namespace NST
 //------------------------------------------------------------------------------
-#endif //NFS3_TYPES_RPCGEN_H
+#endif//NFS3_TYPES_RPCGEN_H
 //------------------------------------------------------------------------------
